@@ -213,7 +213,7 @@ inline ZT &MatGSO<ZT, FT>::sqnorm_coordinates(ZT &sqnorm, vector<ZT> coordinates
   ZT tmp;
   sqnorm = 0;
   vector_matrix_product(tmpvec, coordinates, b);
-  for (int j = 0; j < b.get_rows(); j++)
+  for (size_t j = 0; j < tmpvec.size(); j++)
   {
     tmp.mul(tmpvec[j], tmpvec[j]);
     sqnorm.add(sqnorm, tmp);
